Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CSAF ¶
type CSAF struct {
Document DocumentMetadata `json:"document"`
ProductTree ProductBranch `json:"product_tree"`
Vulnerabilities []Vulnerability `json:"vulnerabilities"`
}
func (*CSAF) FirstProductName ¶
type DocumentMetadata ¶
type ProductBranch ¶
type ProductBranch struct {
Category string `json:"category"`
Name string `json:"name"`
Branches []ProductBranch `json:"branches"`
Product Product `json:"product,omitempty"`
}
func (*ProductBranch) FindFirstProduct ¶
func (branch *ProductBranch) FindFirstProduct() string
FindFirstProduct recursively searches for the first product in the tree
func (*ProductBranch) FindProductIdentifier ¶
func (branch *ProductBranch) FindProductIdentifier(helperType, helperValue string) *Product
FindFirstProduct recursively searches for the first product in the tree
type ThreatData ¶
type Vulnerability ¶
type Vulnerability struct {
CVE string `json:"cve"`
ProductStatus map[string][]string `json:"product_status"`
Threats []ThreatData `json:"threats"`
}
Click to show internal directories.
Click to hide internal directories.